@@ -39,33 +39,27 @@
 #include <torrent/torrentcreator.h>
 #include <torrent/server.h>
 #include <peer/authenticationmonitor.h>
-
-#ifdef GetCurrentTime
-#undef GetCurrentTime // on windows this is a define to GetTickCount
-#endif 
-
 #include <util/log.h>
 #include <util/error.h>
 #include <util/fileops.h>
 #include <util/functions.h>
 #include <util/waitjob.h>
+#include <bcodec/bencoder.h>
 #include <plugin/pluginmanager.h>
 #include <groups/groupmanager.h>
 #include <groups/group.h>
-#include <torrent/jobqueue.h>
-
-#ifdef ENABLE_DHT_SUPPORT
 #include <dht/dht.h>
-#endif
-
+#include <utp/utpserver.h>
+#include <net/socketmonitor.h>
+#include <torrent/jobqueue.h>
 #include "settings.h"
 #include "core.h"
-#include "fileselectdlg.h"
-#include "missingfilesdlg.h"
+#include "dialogs/fileselectdlg.h"
+#include "dialogs/missingfilesdlg.h"
 #include "gui.h"
-#include "torrentmigratordlg.h"
+#include "dialogs/torrentmigratordlg.h"
 #include "scanlistener.h"
-
+#include "tools/magnetmodel.h"
 
 
 using namespace bt;
@@ -74,7 +68,7 @@ namespace kt
 {
 	const Uint32 CORE_UPDATE_INTERVAL = 250;
 
-	Core::Core(kt::GUI* gui) : gui(gui),keep_seeding(true),sleep_suppression_cookie(-1)
+	Core::Core(kt::GUI* gui) : gui(gui),keep_seeding(true),sleep_suppression_cookie(-1),exiting(false)
 	{
 		UpdateCurrentTime();
 		qman = new QueueManager();
@@ -104,13 +98,6 @@ namespace kt
 
 		connect(&update_timer,SIGNAL(timeout()),this,SLOT(update()));
 		
-		Uint16 port = Settings::port();
-		if (port == 0)
-		{
-			port = 6881;
-			Settings::setPort(6881);
-		}
-		
 		// Make sure network interface is set properly before server is initialized
 		if (Settings::networkInterface() != 0)
 		{
@@ -123,40 +110,23 @@ namespace kt
 		}
 		
 		
-		Uint16 i = 0;
-		do
-		{
-			Globals::instance().initServer(port + i);
-			i++;
-		}
-		while (!Globals::instance().getServer().isOK() && i < 10);
-
-		if (Globals::instance().getServer().isOK())
-		{
-			if (port != port + i - 1)
-				gui->infoMsg(i18n("Specified port (%1) is unavailable or in"
-						" use by another application. KTorrent is now using port %2.",
-						 port,QString::number(port + i - 1)));
-
-			Out(SYS_GEN|LOG_NOTICE) << "Bound to port " << (port + i - 1) << endl;
-		}
-		else
-		{
-			gui->errorMsg(i18n("KTorrent is unable to accept connections because the ports %1 to %2 are "
-				   "already in use by another program.",port,QString::number(port + i - 1)));
-			Out(SYS_GEN|LOG_IMPORTANT) << "Cannot find free port" << endl;
-		}
-
+		startServers();
 		
+		magnet = new kt::MagnetModel(this);
 		pman = new kt::PluginManager(this,gui);
 		gman = new kt::GroupManager();
 		applySettings();
 		gman->loadGroups();
+		
 		connect(qman,SIGNAL(queueOrdered()),this,SLOT(startUpdateTimer()));
-		connect(qman,SIGNAL(pauseStateChanged(bool)),gui,SLOT(onPausedStateChanged(bool)));
+		connect(qman,SIGNAL(suspendStateChanged(bool)),gui,SLOT(onSuspendedStateChanged(bool)));
+		connect(magnet,SIGNAL(metadataFound(bt::MagnetLink,QByteArray,bool)),
+				this,SLOT(onMetadataDownloaded(bt::MagnetLink,QByteArray,bool)));
 		
 		if (!Settings::oldTorrentsImported()) // check for old torrents if this hasn't happened yet
 			QTimer::singleShot(1000,this,SLOT(checkForKDE3Torrents()));
+		
+		magnet->loadMagnets(kt::DataDir() + "magnets");
 	}
 	
 	Core::~Core()
@@ -165,9 +135,90 @@ namespace kt
 		delete pman;
 		delete gman;
 	}
+	
+	
+	void Core::startServers()
+	{
+		Uint16 port = Settings::port();
+		if (port == 0)
+		{
+			port = 6881;
+			Settings::setPort(6881);
+		}
+		
+		if (Settings::utpEnabled())
+		{
+			startUTPServer(port);
+			if (!Settings::onlyUseUtp())
+				startTCPServer(port);
+		}
+		else
+		{
+			startTCPServer(port);
+		}
+		ServerInterface::setPort(port);
+	}
+	
+	void Core::startTCPServer(bt::Uint16 port)
+	{
+		if (Globals::instance().initTCPServer(port))
+		{  
+			Out(SYS_GEN|LOG_NOTICE) << "Bound to TCP port " << port << endl;
+		}
+		else
+		{
+			gui->errorMsg(i18n("KTorrent is unable to accept connections because the TCP ports %1 is "
+							"already in use by another program.",port));
+			Out(SYS_GEN|LOG_IMPORTANT) << "Cannot find free TCP port" << endl;
+		}
+	}
+
+	void Core::startUTPServer(bt::Uint16 port)
+	{
+		if (Globals::instance().initUTPServer(port))
+		{
+			Out(SYS_GEN|LOG_NOTICE) << "Bound to UDP port " << port << endl;
+		}
+		else
+		{
+			gui->errorMsg(i18n("KTorrent is unable to accept connections because the UDP port %1 is "
+					"already in use by another program.",port));
+			Out(SYS_GEN|LOG_IMPORTANT) << "Cannot find free UDP port" << endl;
+		}
+	}
+
+
 
 	void Core::applySettings()
 	{
+		bt::Uint16 port = Settings::port();
+		bt::Uint16 current_port = ServerInterface::getPort();
+		
+		bool utp_enabled = Settings::utpEnabled();
+		bool tcp_enabled = utp_enabled && Settings::onlyUseUtp() ? false : true;
+		
+		bt::Globals & globals = bt::Globals::instance();
+		
+		if (globals.isTCPEnabled() && !tcp_enabled)
+			globals.shutdownTCPServer();
+		else if (!globals.isTCPEnabled() && tcp_enabled)
+			startTCPServer(port);
+		else if (tcp_enabled && port != current_port)
+			globals.getTCPServer().changePort(port);
+		
+		if (globals.isUTPEnabled() && !utp_enabled)
+			globals.shutdownUTPServer();
+		else if (!globals.isUTPEnabled() && utp_enabled)
+			startUTPServer(port);
+		else if (utp_enabled && port != current_port)
+			globals.getUTPServer().changePort(port);
+		
+		if (utp_enabled)
+			globals.getUTPServer().setTOS(Settings::dscp() << 2);
+		
+		ServerInterface::setPort(port);
+		ServerInterface::setUtpEnabled(utp_enabled,Settings::onlyUseUtp());
+		ServerInterface::setPrimaryTransportProtocol((bt::TransportProtocol)Settings::primaryTransportProtocol());
 		ApplySettings();
 		setMaxDownloads(Settings::maxDownloads());
 		setMaxSeeds(Settings::maxSeeds());
@@ -178,8 +229,6 @@ namespace kt
 			tmp = kt::DataDir();
 		
 		changeDataDir(tmp);
-		changePort(Settings::port());
-		
 		//update QM
 		getQueueManager()->orderQueue();
 		settingsChanged();
@@ -200,6 +249,9 @@ namespace kt
 		if (Settings::maxSeedTime() > 0)
 			tc->setMaxSeedTime(Settings::maxSeedTime());
 
+		if (Settings::useCompletedDir() && silently)
+			tc->setMoveWhenCompletedDir(Settings::completedDir());
+
 		if (!silently)
 		{
 			if (!gui->selectFiles(tc,&start_torrent,group,location,&skip_check))
@@ -221,21 +273,6 @@ namespace kt
 			{
 				g->addTorrent(tc,true);
 				gman->saveGroups();
-				
-				// check if we need to use the default save location of the group
-				QString dn = g->groupPolicy().default_save_location;
-				if (!dn.isNull() && bt::Exists(dn))
-				{
-					if (!dn.endsWith(bt::DirSeparator()))
-						dn += bt::DirSeparator();
-					
-					QString ddir = tc->getDataDir();
-					if (!ddir.endsWith(bt::DirSeparator()))
-						ddir += bt::DirSeparator();
-
-					if (dn != ddir) // only change when really needed
-						tc->changeOutputDir(dn, 0);
-				}
 			}
 		}
 		
@@ -275,9 +312,8 @@ namespace kt
 		}
 			
 		tc->setPreallocateDiskSpace(true);
-		
-		torrentAdded(tc);
 		qman->torrentAdded(tc,start_torrent);
+		
 		//now copy torrent file to user specified dir if needed
 		if(Settings::useTorrentCopyDir())
 		{
@@ -293,6 +329,8 @@ namespace kt
 			destination += tc->getStats().torrent_name + ".torrent";
 			KIO::file_copy(torFile,destination,-1, KIO::HideProgressInfo);
 		}
+		
+		torrentAdded(tc);
 		return true;
 	}
 	
@@ -306,7 +344,7 @@ namespace kt
 			tc = new TorrentControl();
 			tc->init(qman, data, tdir, dir);
 			tc->setLoadUrl(url);
-			
+
 			if(!init(tc,group,dir,silently))
 				loadingFinished(url, false, true);
 			else
@@ -315,25 +353,31 @@ namespace kt
 			startUpdateTimer();
 			return true;
 		}
+		catch (bt::Warning & warning)
+		{
+			bt::Out(SYS_GEN|LOG_NOTICE) << warning.toString() << endl;
+			if (!silently)
+				gui->infoMsg(warning.toString());
+			else
+				canNotLoadSilently(warning.toString());
+		}
 		catch (bt::Error & err)
 		{
+			bt::Out(SYS_GEN|LOG_IMPORTANT) << err.toString() << endl;
 			if (!silently)
 				gui->errorMsg(err.toString());
 			else
 				canNotLoadSilently(err.toString());
-			
-			bt::Out(SYS_GEN|LOG_IMPORTANT) << err.toString() << endl;
-			
-			delete tc;
-			tc = 0;
-			// delete tdir if necesarry
-			if (bt::Exists(tdir))
-				bt::Delete(tdir,true);
-			
-			loadingFinished(url, false, false);
-			
-			return false;
 		}
+		
+		delete tc;
+		tc = 0;
+		// delete tdir if necesarry
+		if (bt::Exists(tdir))
+			bt::Delete(tdir,true);
+		
+		loadingFinished(url, false, false);
+		return false;
 	}
 
 	bool Core::loadFromFile(const QString & target,const QString & dir,const QString & group,bool silently)
@@ -346,27 +390,34 @@ namespace kt
 			tc = new TorrentControl();
 			tc->init(qman, target, tdir, dir);
 			tc->setLoadUrl(KUrl(target));
-			
+
 			init(tc,group,dir,silently);
 			startUpdateTimer();
 			return true;
 		}
+		catch (bt::Warning & warning)
+		{
+			bt::Out(SYS_GEN|LOG_NOTICE) << warning.toString() << endl;
+			if (!silently)
+				gui->infoMsg(warning.toString());
+			else
+				canNotLoadSilently(warning.toString());
+		}
 		catch (bt::Error & err)
 		{
+			bt::Out(SYS_GEN|LOG_IMPORTANT) << err.toString() << endl;
 			if (!silently)
 				gui->errorMsg(err.toString());
 			else
 				canNotLoadSilently(err.toString());
-			
-			bt::Out(SYS_GEN|LOG_IMPORTANT) << err.toString() << endl;
-			
-			delete tc;
-			tc = 0;
-			// delete tdir if necesarry
-			if (bt::Exists(tdir))
-				bt::Delete(tdir,true);
-			return false;
 		}
+		
+		delete tc;
+		tc = 0;
+		// delete tdir if necesarry
+		if (bt::Exists(tdir))
+			bt::Delete(tdir,true);
+		return false;
 	}
 
 	void Core::downloadFinished(KJob *job)
@@ -387,14 +438,15 @@ namespace kt
 		else
 		{
 			// load in the file (target is always local)
-			QString dir = locationHint();
 			QString group;
-			if (add_to_groups.contains(j))
+			QMap<KUrl,QString>::iterator i = add_to_groups.find(j->url());
+			if (i != add_to_groups.end())
 			{
-				group = add_to_groups[j];
-				add_to_groups.remove(j);
+				group = i.value();
+				add_to_groups.erase(i);
 			}
 		
+			QString dir = locationHint(group);
 			if (dir != QString::null && loadFromData(j->data(),dir,group,false, j->url()))
 				loadingFinished(j->url(),true,false);
 			else
@@ -404,10 +456,14 @@ namespace kt
 
 	void Core::load(const KUrl& url,const QString & group)
 	{
-		if (url.isLocalFile())
+		if (url.protocol() == "magnet")
+		{
+			load(bt::MagnetLink(url.prettyUrl()),group);
+		}
+		else if (url.isLocalFile())
 		{
 			QString path = url.toLocalFile();
-			QString dir = locationHint();
+			QString dir = locationHint(group);
 			if (dir != QString::null && loadFromFile(path,dir,group,false))
 				loadingFinished(url,true,false);
 			else
@@ -418,7 +474,7 @@ namespace kt
 			KIO::Job* j = KIO::storedGet(url);
 			connect(j,SIGNAL(result(KJob*)),this,SLOT(downloadFinished( KJob* )));
 			if (!group.isNull())
-				add_to_groups.insert(j,group);
+				add_to_groups.insert(url,group);
 		}
 	}
 
@@ -433,6 +489,7 @@ namespace kt
 		else if (err)
 		{
 			loadingFinished(j->url(),false,false);
+			canNotLoadSilently(j->errorString());
 		}
 		else
 		{
@@ -456,10 +513,11 @@ namespace kt
 			}
 			
 			QString group;
-			if (add_to_groups.contains(j))
+			QMap<KUrl,QString>::iterator i = add_to_groups.find(j->url());
+			if (i != add_to_groups.end())
 			{
-				group = add_to_groups[j];
-				add_to_groups.remove(j);
+				group = i.value();
+				add_to_groups.erase(i);
 			}
 				
 			
@@ -472,10 +530,14 @@ namespace kt
 
 	void Core::loadSilently(const KUrl& url,const QString & group)
 	{
-		if (url.isLocalFile())
+		if (url.protocol() == "magnet")
+		{
+			loadSilently(bt::MagnetLink(url.prettyUrl()),group);
+		}
+		else if (url.isLocalFile())
 		{
 			QString path = url.toLocalFile(); 
-			QString dir = locationHint();
+			QString dir = locationHint(group);
 		
 			if (dir != QString::null && loadFromFile(path,dir,group,true))
 				loadingFinished(url,true,false);
@@ -488,7 +550,7 @@ namespace kt
 			KIO::Job* j = KIO::storedGet(url);
 			connect(j,SIGNAL(result(KJob*)),this,SLOT(downloadFinishedSilently( KJob* )));
 			if (!group.isNull())
-				add_to_groups.insert(j,group);
+				add_to_groups.insert(url,group);
 		}
 	}
 	
@@ -496,7 +558,7 @@ namespace kt
 	{
 		QString dir;
 		if (savedir.isEmpty() || !bt::Exists(savedir))
-			dir = locationHint();
+			dir = locationHint(group);
 		else
 			dir = savedir;
 		
@@ -510,7 +572,7 @@ namespace kt
 	{
 		QString dir;
 		if (savedir.isEmpty() || !bt::Exists(savedir))
-			dir = locationHint();
+			dir = locationHint(group);
 		else
 			dir = savedir;
 		
@@ -522,9 +584,17 @@ namespace kt
 	
 	void Core::start(bt::TorrentInterface* tc)
 	{
-		TorrentStartResponse reason = qman->start(tc);
-		if (reason == NOT_ENOUGH_DISKSPACE || reason == QM_LIMITS_REACHED)
-			canNotStart(tc,reason);
+		if (tc->getStats().paused)
+		{
+			tc->unpause();
+		}
+		else
+		{
+			TorrentStartResponse reason = qman->start(tc);
+			if (reason == NOT_ENOUGH_DISKSPACE || reason == QM_LIMITS_REACHED)
+				canNotStart(tc,reason);
+		}
+		
 		startUpdateTimer(); // restart update timer
 	}
 	
@@ -533,6 +603,18 @@ namespace kt
 		if (todo.isEmpty())
 			return;
 		
+		// unpause paused torrents
+		for (QList<bt::TorrentInterface*>::iterator i = todo.begin();i != todo.end();)
+		{
+			if ((*i)->getStats().paused)
+			{
+				(*i)->unpause();
+				i = todo.erase(i);
+			}
+			else
+				i++;
+		}
+		
 		if (todo.count() == 1)
 		{
 			start(todo.front());
@@ -540,8 +622,9 @@ namespace kt
 		else
 		{
 			qman->start(todo);
-			startUpdateTimer(); // restart update timer
 		}
+		
+		startUpdateTimer(); // restart update timer
 	}
 
 	void Core::stop(bt::TorrentInterface* tc)
@@ -553,6 +636,19 @@ namespace kt
 	{
 		qman->stop(todo);
 	}
+	
+	void Core::pause(TorrentInterface* tc)
+	{
+		tc->pause();
+	}
+
+	void Core::pause(QList<bt::TorrentInterface*>& todo)
+	{
+		foreach (bt::TorrentInterface* tc,todo)
+		{
+			tc->pause();
+		}
+	}
 
 	QString Core::findNewTorrentDir() const
 	{
@@ -588,8 +684,6 @@ namespace kt
 				
 			qman->append(tc);
 			connectSignals(tc);
-			if (tc->getStats().autostart && !bt::QueueManagerInterface::enabled() && !tc->overMaxRatio() && !tc->overMaxSeedTime())
-				start(tc);
 			torrentAdded(tc);
 		}
 		catch (bt::Error & err)
@@ -597,6 +691,12 @@ namespace kt
 			gui->errorMsg(err.toString());
 			delete tc;
 		}
+		catch (bt::Warning & warning)
+		{
+			bt::Out(SYS_GEN|LOG_NOTICE) << warning.toString() << endl;
+			gui->infoMsg(warning.toString());
+			bt::Delete(tor_dir,true);
+		}
 	}
 
 	void Core::loadTorrents()
@@ -614,12 +714,20 @@ namespace kt
 			Out(SYS_GEN|LOG_NOTICE) << "Loading " << idir << endl;
 			loadExistingTorrent(idir);
 		}
+		
+		gman->torrentsLoaded(qman);
+		QTimer::singleShot(0,this,SLOT(delayedStart()));
+	}
+	
+	void Core::delayedStart()
+	{
 		if (!kt::QueueManager::enabled())
 			qman->startAutoStartTorrents();
 		else
 			qman->orderQueue();
 	}
 
+
 	void Core::remove(bt::TorrentInterface* tc,bool data_to)
 	{
 		try
@@ -668,6 +776,65 @@ namespace kt
 		}
 	}
 	
+	void Core::remove(QList<bt::TorrentInterface*> & todo, bool data_to)
+	{
+		QList<bt::TorrentInterface*>::iterator i = todo.begin();
+		while (i != todo.end())
+		{
+			bt::TorrentInterface* tc = *i;
+			if (tc->getJobQueue()->runningJobs())
+			{
+				// if there are running jobs, schedule delete when they finish
+				delayed_removal.insert(tc,data_to);
+				connect(tc,SIGNAL(runningJobsDone(bt::TorrentInterface*)),
+						this,SLOT(delayedRemove(bt::TorrentInterface*)));
+				i = todo.erase(i);
+			}
+			else
+				i++;
+		}
+		
+		stop(todo);
+		
+		foreach (bt::TorrentInterface* tc,todo)
+		{
+			const bt::TorrentStats & s = tc->getStats();
+			removed_bytes_up += s.session_bytes_uploaded;
+			removed_bytes_down += s.session_bytes_downloaded;
+			
+			QString dir = tc->getTorDir();
+			
+			try
+			{
+				if (data_to)
+					tc->deleteDataFiles();
+			}
+			catch (Error & e)
+			{
+				gui->errorMsg(e.toString());
+			}
+			
+			// cleanup potential data scans
+			QMap<bt::TorrentInterface*,ScanListener*>::iterator i = active_scans.find(tc);
+			if (i != active_scans.end())
+				closeScanListener(i.value());
+			
+			torrentRemoved(tc);
+			gman->torrentRemoved(tc);
+			try
+			{
+				bt::Delete(dir,false);
+			}
+			catch (Error & e)
+			{
+				gui->errorMsg(e.toString());
+			}
+		}
+		
+		qman->torrentsRemoved(todo);
+		gui->updateActions();
+	}
+	
 	void Core::delayedRemove(bt::TorrentInterface* tc)
 	{
 		if (!delayed_removal.contains(tc))
@@ -703,16 +870,16 @@ namespace kt
 
 	void Core::onExit()
 	{
-#ifdef ENABLE_DHT_SUPPORT
+		// stop timer to prevent updates during wait
+		exiting = true;
+		update_timer.stop();
+		
+		net::SocketMonitor::instance().shutdown();
+		magnet->saveMagnets(kt::DataDir() + "magnets");
 		// make sure DHT is stopped
 		Globals::instance().getDHT().stop();
-#endif
-		// stop timer to prevent updates during wait
-		update_timer.stop();
 		// stop all authentications going on
 		AuthenticationMonitor::instance().clear();
-		// shutdown the server
-		Globals::instance().shutdownServer();
 		
 		WaitJob* job = new WaitJob(5000);
 		qman->onExit(job);
@@ -724,8 +891,14 @@ namespace kt
 		else
 			delete job;
 		
+		// shutdown the servers
+		Globals::instance().shutdownTCPServer();
+		Globals::instance().shutdownUTPServer();
+		
 		pman->unloadAll();
 		qman->clear();
+		// Sync the config to be sure everything is saved
+		Settings::self()->writeConfig();
 	}
 
 	bool Core::changeDataDir(const QString & new_dir)
@@ -749,7 +922,7 @@ namespace kt
 
 			Out(SYS_GEN|LOG_DEBUG) << "Switching to datadir " << nd << endl;
 			
-			qman->setPausedState(true);
+			qman->setSuspendedState(true);
 			
 			QList<bt::TorrentInterface*> succes;
 
@@ -764,7 +937,7 @@ namespace kt
 					// set back the old data_dir in Settings
 					Settings::setTempDir(data_dir);
 					Settings::self()->writeConfig();
-					qman->setPausedState(false);
+					qman->setSuspendedState(false);
 					update_timer.start(CORE_UPDATE_INTERVAL);
 					return false;
 				}
@@ -775,7 +948,7 @@ namespace kt
 				i++;
 			}
 			data_dir = nd;
-			qman->setPausedState(false);
+			qman->setSuspendedState(false);
 			update_timer.start(CORE_UPDATE_INTERVAL);
 			return true;
 		}
@@ -834,6 +1007,9 @@ namespace kt
 
 	void Core::update()
 	{
+		if (exiting)
+			return;
+		
 		try
 		{
 			bt::UpdateCurrentTime();
@@ -852,7 +1028,7 @@ namespace kt
 				i++;
 			}
 			
-			if (!updated)
+			if (!updated && magnet->rowCount() == 0)
 			{
 				Out(SYS_GEN|LOG_DEBUG) << "Stopped update timer" << endl;
 				update_timer.stop(); // stop timer when not necessary
@@ -865,9 +1041,10 @@ namespace kt
 			}
 			else
 			{
+				magnet->updateMagnetDownloaders();
 				// check if the priority of stalled torrents must be decreased
 				if (Settings::decreasePriorityOfStalledTorrents())
-					qman->checkStalledTorrents(bt::GetCurrentTime(),Settings::stallTimer());
+					qman->checkStalledTorrents(bt::CurrentTime(),Settings::stallTimer());
 			}
 		}
 		catch (bt::Error & err)
@@ -875,32 +1052,14 @@ namespace kt
 			Out(SYS_GEN|LOG_IMPORTANT) << "Caught bt::Error: " << err.toString() << endl;
 		}
 	}
-
-	bt::TorrentInterface* Core::makeTorrent(const QString & file,const QStringList & trackers,const KUrl::List & webseeds,
-				int chunk_size,const QString & name,
-				const QString & comments,bool seed,
-				const QString & output_file,bool priv_tor,QProgressBar* prog, bool decentralized)
+	
+	bt::TorrentInterface* Core::createTorrent(bt::TorrentCreator* mktor,bool seed)
 	{
 		QString tdir;
 		try
 		{
-			if (chunk_size < 0)
-				chunk_size = 256;
-
-			bt::TorrentCreator mktor(file,trackers,webseeds,chunk_size,name,comments,priv_tor, decentralized);
-			prog->setMaximum(mktor.getNumChunks());
-			Uint32 ns = 0;
-			while (!mktor.calculateHash())
-			{
-				prog->setValue(ns);
-				ns++;
-				if (ns % 10 == 0)
-					KApplication::kApplication()->processEvents();
-			}
-
-			mktor.saveTorrent(output_file);
 			tdir = findNewTorrentDir();
-			bt::TorrentInterface* tc = mktor.makeTC(tdir);
+			bt::TorrentControl* tc = mktor->makeTC(tdir);
 			if (tc)
 			{
 				connectSignals(tc);
@@ -916,13 +1075,14 @@ namespace kt
 			// cleanup if necessary
 			if (bt::Exists(tdir))
 				bt::Delete(tdir,true);
-
+			
 			// Show error message
 			gui->errorMsg(i18n("Cannot create torrent: %1",e.toString()));
 		}
 		return 0;
 	}
 
+
 	CurrentStats Core::getStats()
 	{
 		CurrentStats stats;
@@ -949,9 +1109,24 @@ namespace kt
 
 	bool Core::changePort(Uint16 port)
 	{
-		bt::Server & srv = Globals::instance().getServer();
-		srv.changePort(port);
-		return srv.isOK();
+		bool ok = false;
+		if (Settings::utpEnabled())
+		{
+			utp::UTPServer & utp_srv = Globals::instance().getUTPServer();
+			ok = utp_srv.changePort(port);
+			if (!Settings::onlyUseUtp())
+			{
+				bt::Server & srv = Globals::instance().getTCPServer();
+				ok = ok && srv.changePort(port);
+			}
+		}
+		else
+		{
+			bt::Server & srv = Globals::instance().getTCPServer();
+			ok = srv.changePort(port);
+		}
+		
+		return ok;
 	}
 
 	void Core::slotStoppedByError(bt::TorrentInterface* tc, QString msg)
@@ -984,16 +1159,16 @@ namespace kt
 		startUpdateTimer();
 	}
 
-	void Core::setPausedState(bool pause)
+	void Core::setSuspendedState(bool suspend)
 	{
-		qman->setPausedState(pause);
-		if (!pause)
+		qman->setSuspendedState(suspend);
+		if (!suspend)
 			startUpdateTimer();
 	}
 	
-	bool Core::getPausedState()
+	bool Core::getSuspendedState()
 	{
-		return qman->getPausedState();
+		return qman->getSuspendedState();
 	}
 
 	void Core::aboutToBeStarted(bt::TorrentInterface* tc,bool & ret)
@@ -1212,20 +1387,95 @@ namespace kt
 		gui->updateActions();
 	}
 	
-	QString Core::locationHint() const
+	void Core::load(const bt::MagnetLink& mlink,const QString & group)
+	{
+		if (!mlink.isValid())
+		{
+			gui->errorMsg(i18n("Invalid magnet bittorrent link: %1",mlink.toString()));
+		}
+		else
+		{
+			if (!Globals::instance().getDHT().isRunning())
+				dhtNotEnabled(i18n("You are attempting to download a magnet link, and DHT is not enabled. "
+						"For optimum results enable DHT."));
+			magnet->download(mlink,false);
+			startUpdateTimer();
+			if (!group.isNull())
+				add_to_groups.insert(KUrl(mlink.toString()),group);
+		}
+	}
+	
+	void Core::loadSilently(const bt::MagnetLink& mlink,const QString & group)
+	{
+		if (!mlink.isValid())
+		{
+			Out(SYS_GEN|LOG_IMPORTANT) << "Invalid magnet bittorrent link: " << mlink.toString() << endl;
+			canNotLoadSilently(i18n("Invalid magnet bittorrent link: %1",mlink.toString()));
+		}
+		else
+		{
+			if (!Globals::instance().getDHT().isRunning())
+				dhtNotEnabled(i18n("You are attempting to download a magnet link, and DHT is not enabled. "
+							"For optimum results enable DHT."));
+			magnet->download(mlink,true);
+			startUpdateTimer();
+			if (!group.isNull())
+				add_to_groups.insert(KUrl(mlink.toString()),group);
+		}
+	}
+
+	void Core::onMetadataDownloaded(const bt::MagnetLink& mlink, const QByteArray& data,bool silently)
+	{
+		QByteArray tmp;
+		BEncoderBufferOutput* out = new BEncoderBufferOutput(tmp);
+		BEncoder enc(out);
+		enc.beginDict();
+		if (!mlink.tracker().isEmpty())
+		{
+			enc.write("announce");
+			enc.write(mlink.tracker());
+		}
+		enc.write("info");
+		out->write(data.data(),data.size());
+		enc.end();
+		
+		KUrl url = mlink.toString();
+		QString group;
+		QMap<KUrl,QString>::iterator i = add_to_groups.find(url);
+		if (i != add_to_groups.end())
+		{
+			group = i.value();
+			add_to_groups.erase(i);
+		}
+		
+		if (silently)
+			loadSilently(tmp,url,group,QString());
+		else
+			load(tmp,url,group,QString());
+	}
+
+
+	QString Core::locationHint(const QString & group) const
 	{
 		QString dir;
-		if (Settings::useSaveDir())
+		
+		// First see if we can use the group settings
+		Group* g = gman->find(group);
+		QString group_save_location = g != 0 ? g->groupPolicy().default_save_location : QString();
+		if (!group_save_location.isEmpty() && bt::Exists(group_save_location))
+			dir = g->groupPolicy().default_save_location;
+		else if (Settings::useSaveDir())
 			dir = Settings::saveDir().toLocalFile();
 		else
 			dir = Settings::lastSaveDir();
 		
 		
-		if (dir.isEmpty() || !QDir(dir).exists())
+		if (dir.isEmpty() || !bt::Exists(dir))
 			dir = QDir::homePath();
 		
 		return dir;
 	}
+
 }
 
 #include "core.moc"
