@@ -18,9 +18,9 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
-#include <qtimer.h>
+
+#include <QTimer>
 #include <QClipboard>
-#include <QToolButton>
 #include <kconfig.h>
 #include <klocale.h>
 #include <kaction.h>
@@ -45,6 +45,7 @@
 #include <torrent/queuemanager.h>
 #include <torrent/torrentcontrol.h>
 #include <util/log.h>
+#include <util/error.h>
 #include <dht/dhtbase.h>
 #include <groups/group.h>
 #include <groups/groupmanager.h>
@@ -52,26 +53,26 @@
 #include <settings.h>
 #include "gui.h"
 #include "core.h"
-#include "view.h"
-#include "viewmanager.h"
-#include "fileselectdlg.h"
-#include "prefdialog.h"
+#include "view/view.h"
+#include "view/viewmanager.h"
+#include "dialogs/fileselectdlg.h"
+#include "pref/prefdialog.h"
 #include "statusbar.h"
-#include "groupview.h"
-#include "scandlg.h"
+#include "groups/groupview.h"
 #include "trayicon.h"
 #include "dbus/dbus.h"
-#include "pastedialog.h"
+#include "dialogs/pastedialog.h"
 #include "ipfilterwidget.h"
-#include "torrentcreatordlg.h"
-#include "importdialog.h"
-#include "queuemanagerwidget.h"
+#include "dialogs/torrentcreatordlg.h"
+#include "dialogs/importdialog.h"
+#include "tools/queuemanagerwidget.h"
 #include <util/timer.h>
 #include <gui/activitybar.h>
 #include "torrentactivity.h"
 #include <gui/centralwidget.h>
 
 
+
 namespace kt
 {
 	GUI::GUI() : core(0),pref_dlg(0)
@@ -268,16 +269,16 @@ namespace kt
 		}
 	}
 	
-	void GUI::pauseQueue(bool pause)
+	void GUI::suspendQueue(bool suspend)
 	{
-		Out(SYS_GEN|LOG_NOTICE) << "Setting paused state to " << pause << endl;
-		core->setPausedState(pause);
+		Out(SYS_GEN|LOG_NOTICE) << "Setting suspended state to " << suspend << endl;
+		core->setSuspendedState(suspend);
 		torrent_activity->updateActions();
 	}
 	
-	void GUI::onPausedStateChanged(bool paused)
+	void GUI::onSuspendedStateChanged(bool suspended)
 	{
-		queue_pause_action->setChecked(paused);
+		queue_suspend_action->setChecked(suspended);
 	}
 	
 	void GUI::startAllTorrents()
@@ -293,7 +294,9 @@ namespace kt
 	void GUI::pasteURL()
 	{
 		PasteDialog dlg(core, this);
+		dlg.loadState(KGlobal::config());
 		dlg.exec();
+		dlg.saveState(KGlobal::config());
 	}
 	
 	void GUI::paste()
@@ -382,7 +385,7 @@ namespace kt
 		connect(open_silently_action,SIGNAL(triggered()),this,SLOT(openTorrentSilently()));
 		ac->addAction("file_open_silently",open_silently_action);
 				
-		KAction* quit_action = KStandardAction::quit(kapp, SLOT(quit()), ac);
+		KStandardAction::quit(kapp, SLOT(quit()), ac);
 		show_status_bar_action = KStandardAction::showStatusbar(this, SLOT(showStatusBar()),ac);
 		show_status_bar_action->setIcon(KIcon("kt-show-statusbar"));
 		show_menu_bar_action = KStandardAction::showMenubar(this, SLOT(showMenuBar()),ac);
@@ -395,23 +398,25 @@ namespace kt
 		start_all_action = new KAction(KIcon("kt-start-all"),i18n("Start All"),this);
 		start_all_action->setToolTip(i18n("Start all torrents"));
 		connect(start_all_action,SIGNAL(triggered()),this,SLOT(startAllTorrents()));
+		ac->addAction("start_all",start_all_action);
 		
 		stop_all_action = new KAction(KIcon("kt-stop-all"),i18n("Stop All"),this);
 		stop_all_action->setToolTip(i18n("Stop all torrents"));
 		connect(stop_all_action,SIGNAL(triggered()),this,SLOT(stopAllTorrents()));
+		ac->addAction("stop_all",stop_all_action);
 		
-		paste_url_action = new KAction(KIcon(open_action->icon()),i18n("Open URL"),this);
-		paste_url_action->setToolTip(i18n("Open a URL which points to a torrent"));
+		paste_url_action = new KAction(KIcon("document-open-remote"),i18n("Open URL"),this);
+		paste_url_action->setToolTip(i18n("Open a URL which points to a torrent, magnet links are supported"));
 		paste_url_action->setShortcut(KShortcut(Qt::CTRL + Qt::Key_P));
 		connect(paste_url_action,SIGNAL(triggered()),this,SLOT(pasteURL()));
 		ac->addAction("paste_url",paste_url_action);
 		
-		queue_pause_action = new KToggleAction(KIcon("kt-pause"),i18n("Pause KTorrent"),this);
-		ac->addAction("queue_pause",queue_pause_action);
-		queue_pause_action->setToolTip(i18n("Pause all running torrents"));
-		queue_pause_action->setShortcut(KShortcut(Qt::SHIFT + Qt::Key_P));
-		queue_pause_action->setGlobalShortcut(KShortcut(Qt::ALT + Qt::SHIFT + Qt::Key_P));
-		connect(queue_pause_action,SIGNAL(toggled(bool)),this,SLOT(pauseQueue(bool)));
+		queue_suspend_action = new KToggleAction(KIcon("kt-pause"),i18n("Suspend Torrents"),this);
+		ac->addAction("queue_suspend",queue_suspend_action);
+		queue_suspend_action->setToolTip(i18n("Suspend all running torrents"));
+		queue_suspend_action->setShortcut(KShortcut(Qt::SHIFT + Qt::Key_P));
+		queue_suspend_action->setGlobalShortcut(KShortcut(Qt::ALT + Qt::SHIFT + Qt::Key_P));
+		connect(queue_suspend_action,SIGNAL(toggled(bool)),this,SLOT(suspendQueue(bool)));
 		
 		ipfilter_action = new KAction(KIcon("view-filter"),i18n("IP Filter"),this);
 		ipfilter_action->setToolTip(i18n("Show the list of blocked IP addresses"));
@@ -448,30 +453,26 @@ namespace kt
 		
 		setStandardToolBarMenuEnabled(true);
 				
-		QMenu* m = tray_icon->contextMenu();
-		m->addAction(start_all_action);
-		m->addAction(stop_all_action);
-		m->addAction(queue_pause_action);
-		m->addSeparator();
-		m->addAction(paste_url_action);
-		m->addAction(open_action);
-		m->addSeparator();
-		m->addAction(pref_action);
-		m->addAction(show_kt_action);
-		m->addSeparator();
-		m->addAction(quit_action);
+		
 	}
 
 	void GUI::update()
 	{
-		CurrentStats stats = core->getStats();
-		status_bar->updateSpeed(stats.upload_speed,stats.download_speed);
-		status_bar->updateTransfer(stats.bytes_uploaded,stats.bytes_downloaded);
-		status_bar->updateDHTStatus(Globals::instance().getDHT().isRunning(),Globals::instance().getDHT().getStats());
+		try
+		{
+			CurrentStats stats = core->getStats();
+			status_bar->updateSpeed(stats.upload_speed,stats.download_speed);
+			status_bar->updateTransfer(stats.bytes_uploaded,stats.bytes_downloaded);
+			status_bar->updateDHTStatus(Globals::instance().getDHT().isRunning(),Globals::instance().getDHT().getStats());
 
-		tray_icon->updateStats(stats);
-		core->updateGuiPlugins();
-		torrent_activity->update();
+			tray_icon->updateStats(stats);
+			core->updateGuiPlugins();
+			torrent_activity->update();
+		}
+		catch (bt::Error & err)
+		{
+			Out(SYS_GEN|LOG_IMPORTANT) << "Uncaught exception: " << err.toString() << endl;
+		}
 	}
 
 	void GUI::applySettings()
@@ -557,7 +558,6 @@ namespace kt
 		{
 			saveState(KGlobal::config());
 			timer.stop();
-			ScanDlg::cancelAllScans();
 			hide();
 			tray_icon->hide();
 			core->onExit();
@@ -570,7 +570,7 @@ namespace kt
 	{
 		torrent_activity->updateActions();
 		Uint32 nr = core->getNumTorrentsRunning();
-		queue_pause_action->setEnabled(core->getPausedState() || nr > 0);
+		queue_suspend_action->setEnabled(core->getSuspendedState() || nr > 0);
 		start_all_action->setEnabled(core->getNumTorrentsNotRunning() > 0);
 		stop_all_action->setEnabled(nr > 0);
 	}
@@ -599,6 +599,7 @@ namespace kt
 	{
 		return torrent_activity;
 	}
+
 }
 
 #include "gui.moc"
