@@ -27,6 +27,7 @@
 #include <sys/file.h>
 #include <errno.h>
 #include <fcntl.h>
+#include <exception>
 #include <QDir>
 #include <QFile>
 #include <kurl.h>
@@ -34,10 +35,15 @@
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
 #include "app.h"
-#include "btversion.h"
+#include "version.h"
 #include "ktversion.h"
 #include <kdebug.h>
 #include <torrent/globals.h>
+#include <util/error.h>
+#include <util/log.h>
+#include <util/functions.h>
+
+using namespace bt;
 
 #ifndef Q_WS_WIN
 bool GrabPIDLock()
@@ -68,8 +74,6 @@ bool GrabPIDLock()
 #endif
 
 
-
-
 int main(int argc, char **argv)
 {	
 #ifndef Q_WS_WIN
@@ -84,7 +88,7 @@ int main(int argc, char **argv)
 		"ktorrent", 0, ki18n("KTorrent"),
 		kt::VERSION_STRING, ki18n("Bittorrent client for KDE"),
 		KAboutData::License_GPL, 
-		ki18n("(C) 2005 - 2008 Joris Guisson and Ivan Vasic"), 
+		ki18n("(C) 2005 - 2010 Joris Guisson and Ivan Vasic"), 
 		KLocalizedString(),
 		"http://www.ktorrent.org/");
 
@@ -130,7 +134,10 @@ int main(int argc, char **argv)
 	about.addCredit(ki18n("Aaron J. Seigo"),ki18n("Drag and drop support for plasma applet"),"aseigo@kde.org");
 	about.addCredit(ki18n("Ian Higginson"),ki18n("Patch to cleanup the plugin list"),"xeriouxi@fastmail.fm");
 	about.addCredit(ki18n("Amichai Rothman"),ki18n("Patch to make the plasma applet a popup applet"),"amichai@amichais.net");
+	about.addCredit(ki18n("Leo Trubach"),ki18n("Patch to add support for IP ranges in IP filter dialog"),"leotrubach@gmail.com");
+	about.addCredit(ki18n("Andrei Barbu"),ki18n("Feature which adds the date a torrent was added"),"andrei@0xab.com");
 	KCmdLineArgs::init(argc, argv, &about);
+	about.addCredit(ki18n("Jonas Lundqvist"),ki18n("Feature to disable authentication in the webinterface"),"jonas@gannon.se"); 
 
 	KCmdLineOptions options;
 	options.add("+[Url]", ki18n("Document to open"));
@@ -155,10 +162,7 @@ int main(int argc, char **argv)
 #endif
 
 #ifdef Q_WS_WIN
-	WSADATA wsaData;
-	WORD wVersionRequested = MAKEWORD(2, 2);
-	int err = WSAStartup( wVersionRequested, &wsaData );
-	if (err != 0) 
+	if (!bt::InitWindowsSocketsAPI())
 	{
 		kError()<< "Couldn't load winsock dll";
 		return 0;
@@ -171,9 +175,17 @@ int main(int argc, char **argv)
 		app.setQuitOnLastWindowClosed(false);
 		app.exec();
 	}
+	catch (bt::Error & err)
+	{
+		Out(SYS_GEN|LOG_IMPORTANT) << "Uncaught exception: " << err.toString() << endl;
+	}
+	catch (std::exception & err)
+	{
+		Out(SYS_GEN|LOG_IMPORTANT) << "Uncaught exception: " << err.what() << endl;
+	}
 	catch (...)
 	{
-	//	fprintf(stderr, "Aborted by error : %s\n",e.toString().ascii());
+		Out(SYS_GEN|LOG_IMPORTANT) << "Uncaught unknown exception " << endl;
 	}
 	bt::Globals::cleanup();
 	return 0;
