@@ -18,18 +18,22 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 #include <QBoxLayout>
+#include <QToolBar>
+#include <QTreeView>
 #include <QToolButton>
-#include <klocale.h>
-#include <kicon.h>
+#include <KConfigGroup>
+#include <KLocale>
+#include <KIcon>
 #include <gui/tabbarwidget.h>
 #include <groups/groupmanager.h>
 #include "torrentactivity.h"
-#include "viewmanager.h"
+#include "view/viewmanager.h"
 #include "gui.h"
 #include "core.h"
-#include "view.h"
-#include "groupview.h"
-#include "queuemanagerwidget.h"
+#include "view/view.h"
+#include "groups/groupview.h"
+#include "tools/queuemanagerwidget.h"
+#include "tools/magnetview.h"
 
 
 namespace kt
@@ -49,6 +53,7 @@ namespace kt
 		hsplit = new QSplitter(Qt::Horizontal,vsplit);
 		
 		tabs = new KTabWidget(hsplit);
+		tabs->setMovable(true);
 		connect(tabs,SIGNAL(currentChanged(int)),this,SLOT(currentTabPageChanged(int)));
 		group_view = new GroupView(core->getGroupManager(),view_man,gui,hsplit);
 		connect(group_view,SIGNAL(openNewTab(kt::Group*)),this,SLOT(openNewView(kt::Group*)));
@@ -69,6 +74,10 @@ namespace kt
 		connect(core,SIGNAL(torrentRemoved(bt::TorrentInterface*)),qm,SLOT(onTorrentRemoved(bt::TorrentInterface*)));
 		tool_views->addTab(qm,i18n("Queue Manager"),"kt-queue-manager",i18n("Widget to manage the torrent queue"));
 		
+		magnet_view = new MagnetView(core->getMagnetModel(),this);
+		tool_views->addTab(magnet_view,i18n("Magnet"),"kt-magnet",
+						   i18n("Displays the currently downloading magnet links"));
+		
 		QToolButton* lc = new QToolButton(tabs);
 		tabs->setCornerWidget(lc,Qt::TopLeftCorner);
 		QToolButton* rc = new QToolButton(tabs);
@@ -184,14 +193,16 @@ namespace kt
 		tool_views->loadState(cfg,"TorrentActivityBottomTabBar");
 		notifyViewListeners(view_man->getCurrentTorrent());
 		tabs->cornerWidget(Qt::TopRightCorner)->setEnabled(tabs->count() > 1);
+		magnet_view->loadState(cfg);
 	}
 	
 	void TorrentActivity::saveState(KSharedConfigPtr cfg)
 	{
-		view_man->saveState(cfg);
+		view_man->saveState(cfg,tabs);
 		group_view->saveState(cfg);
 		qm->saveState(cfg);
 		tool_views->saveState(cfg,"TorrentActivityBottomTabBar");
+		magnet_view->saveState(cfg);
 		
 		KConfigGroup g = cfg->group("TorrentActivitySplitters");
 		if (vsplit)
