@@ -242,6 +242,11 @@ namespace kt
 		return ti->getDataDir();
 	}
 	
+	QString DBusTorrent::pathOnDisk() const
+	{
+		return ti->getStats().output_path;
+	}
+	
 	QString DBusTorrent::torDir() const
 	{
 		return ti->getTorDir();
@@ -440,5 +445,36 @@ namespace kt
 		return ti->isAllowedToStart();
 	}
 
+	double DBusTorrent::maxSeedTime() const
+	{
+		return ti->getMaxSeedTime();
+	}
+	
+	double DBusTorrent::maxShareRatio() const
+	{
+		return ti->getMaxShareRatio();
+	}
+	
+	void DBusTorrent::setMaxSeedTime(double hours)
+	{
+		ti->setMaxSeedTime(hours);
+	}
+	
+	void DBusTorrent::setMaxShareRatio(double ratio)
+	{
+		ti->setMaxShareRatio(ratio);
+	}
+		
+	double DBusTorrent::seedTime() const
+	{
+		Uint32 dl = ti->getRunningTimeDL();
+		Uint32 ul = ti->getRunningTimeUL();
+		return (double)(ul - dl) / 3600.0;
+	}
+	
+	double DBusTorrent::shareRatio() const
+	{
+		return ti->getStats().shareRatio();
+	}
 }
 
