@@ -62,11 +62,11 @@ namespace kt
 		Q_SCRIPTABLE qulonglong bytesLeft() const;
 		Q_SCRIPTABLE qulonglong bytesToDownload() const;
 		
-		// Priority
+		// Priority and QM
 		Q_SCRIPTABLE int priority() const;
 		Q_SCRIPTABLE void setPriority(int p);
-		Q_SCRIPTABLE bool isUserControlled() const;
-		Q_SCRIPTABLE void setUserControlled(bool uc);
+		Q_SCRIPTABLE void setAllowedToStart(bool on);
+		Q_SCRIPTABLE bool isAllowedToStart() const;
 		
 		// Chunks
 		Q_SCRIPTABLE uint chunks() const;
@@ -99,6 +99,7 @@ namespace kt
 		Q_SCRIPTABLE uint numFiles() const;
 		Q_SCRIPTABLE QString dataDir() const;
 		Q_SCRIPTABLE QString torDir() const;
+		Q_SCRIPTABLE QString pathOnDisk() const;
 		Q_SCRIPTABLE QString filePath(uint file_index) const;
 		Q_SCRIPTABLE QString filePathOnDisk(uint file_index) const;
 		Q_SCRIPTABLE qulonglong fileSize(uint file_index) const;
@@ -113,6 +114,14 @@ namespace kt
 		// Stats
 		Q_SCRIPTABLE QByteArray stats() const;
 		
+		// Max share ratio and seed time
+		Q_SCRIPTABLE void setMaxShareRatio(double ratio);
+		Q_SCRIPTABLE double maxShareRatio() const;
+		Q_SCRIPTABLE double shareRatio() const;
+		Q_SCRIPTABLE void setMaxSeedTime(double hours);
+		Q_SCRIPTABLE double maxSeedTime() const;
+		Q_SCRIPTABLE double seedTime() const;
+		
 		
 	Q_SIGNALS:
 		Q_SCRIPTABLE void finished(QObject* tor);
