@@ -80,7 +80,6 @@ namespace kt
 		UDPTrackerSocket::setPort(Settings::udpTrackerPort());
 		Choker::setNumUploadSlots(Settings::numUploadSlots());
 
-#ifdef ENABLE_DHT_SUPPORT
 		dht::DHTBase & ht = Globals::instance().getDHT();
 		if (Settings::dhtSupport() && !ht.isRunning())
 		{
@@ -96,17 +95,16 @@ namespace kt
 			ht.stop();
 			ht.start(kt::DataDir() + "dht_table",kt::DataDir() + "dht_key",Settings::dhtPort());
 		}
-#endif
 		
 		UTPex::setEnabled(Settings::pexEnabled());
 		
 		if (Settings::useEncryption())
 		{
-			Globals::instance().getServer().enableEncryption(Settings::allowUnencryptedConnections());
+			ServerInterface::enableEncryption(Settings::allowUnencryptedConnections());
 		}
 		else
 		{
-			Globals::instance().getServer().disableEncryption();
+			ServerInterface::disableEncryption();
 		}
 	
 		if (Settings::useCustomIP())
@@ -125,11 +123,6 @@ namespace kt
 		bt::Cache::setPreallocationEnabled(Settings::diskPrealloc());
 		bt::Cache::setPreallocateFully(Settings::fullDiskPrealloc());
 		
-		if (Settings::useCompletedDir())
-			bt::TorrentControl::setMoveWhenCompletedDir(Settings::completedDir());
-		else
-			bt::TorrentControl::setMoveWhenCompletedDir(KUrl());
-		
 		bt::TorrentControl::setDataCheckWhenCompleted(Settings::checkWhenFinished());
 		bt::TorrentControl::setMinimumDiskSpace(Settings::minDiskSpace());
 		bt::TorrentControl::setAutoRecheck(Settings::autoRecheck());
