@@ -24,6 +24,7 @@
 #include <set>
 #include <qobject.h>
 #include <qlinkedlist.h>
+#include <solid/networking.h>
 #include <interfaces/torrentinterface.h>
 #include <interfaces/queuemanagerinterface.h>
 #include <ktcore_export.h>
@@ -199,13 +200,18 @@ namespace kt
 		void setKeepSeeding(bool ks);
 
 		/**
-		 * Sets global paused state for QueueManager and stopps all running torrents.
+		 * Sets global suspended state for QueueManager and stopps all running torrents.
 		 * No torrents will be automatically started/stopped with QM.
 		 */
-		void setPausedState(bool pause);
+		void setSuspendedState(bool suspend);
 
-		/// Get the paused state
-		bool getPausedState() const {return paused_state;}
+		/// Get the suspended state
+		bool getSuspendedState() const {return suspended_state;}
+		
+		/**
+		 * Reindex the queue priorities.
+		 */
+		void reindexQueue();
 		
 	public slots:
 		/**
@@ -235,15 +241,16 @@ namespace kt
 		void queueOrdered();
 		
 		/**
-		 * Emitted when the paused state changes.
-		 * @param paused The paused state
+		 * Emitted when the suspended state changes.
+		 * @param suspended The suspended state
 		 */
-		void pauseStateChanged(bool paused);
+		void suspendStateChanged(bool suspended);
 
 	public slots:
 		void torrentFinished(bt::TorrentInterface* tc);
 		void torrentAdded(bt::TorrentInterface* tc,bool start_torrent);
 		void torrentRemoved(bt::TorrentInterface* tc);
+		void torrentsRemoved(QList<bt::TorrentInterface*> & tors);
 		void torrentStopped(bt::TorrentInterface* tc);
 		void onLowDiskSpace(bt::TorrentInterface* tc, bool toStop);
 
@@ -255,16 +262,22 @@ namespace kt
 		void checkMaxRatio(QList<bt::TorrentInterface*> & todo);
 		void rearrangeQueue();
 		bt::TorrentStartResponse startInternal(bt::TorrentInterface* tc);
+		bool checkLimits(bt::TorrentInterface* tc,bool interactive);
+		bool checkDiskSpace(bt::TorrentInterface* tc,bool interactive);
+		
+	private slots:
+		void networkStatusChanged(Solid::Networking::Status status);
 
 	private:
 		QueuePtrList downloads;
-		std::set<bt::TorrentInterface*> paused_torrents;
+		std::set<bt::TorrentInterface*> suspended_torrents;
 		int max_downloads;
 		int max_seeds;
-		bool paused_state;
+		bool suspended_state;
 		bool keep_seeding;
 		bool exiting;
 		bool ordering;
+		QDateTime network_down_time;
 	};
 }
 #endif
