@@ -32,6 +32,7 @@
 #include <interfaces/torrentfileinterface.h>
 #include <util/functions.h>
 #include <util/log.h>
+#include <util/error.h>
 
 using namespace bt;
 
@@ -317,7 +318,7 @@ namespace kt
 			if (tc->getStats().multi_file_torrent)
 				constructTree();
 			else
-				root = new Node(0,tc->getStats().torrent_name,tc->getStats().total_chunks);
+				root = new Node(0,tc->getUserModifiedFileName(),tc->getStats().total_chunks);
 		}
 	}
 
@@ -337,7 +338,7 @@ namespace kt
 			if (tc->getStats().multi_file_torrent)
 				constructTree();
 			else
-				root = new Node(0,tc->getStats().torrent_name,tc->getStats().total_chunks);
+				root = new Node(0,tc->getUserModifiedFileName(),tc->getStats().total_chunks);
 		}
 		reset();
 	}
@@ -583,13 +584,22 @@ namespace kt
 		if (!n->file)
 		{
 			// we are in a directory
-			n->name = name;
 			if (!n->parent)
 			{
 				// toplevel directory name has changed
 				tc->setUserModifiedFileName(name);
 			}
+			else
+			{
+				// Check if there is a sibling with the same name
+				foreach (Node* sibling,n->parent->children)
+				{
+					if (sibling != n && sibling->name == name)
+						return false;
+				}
+			}
 			
+			n->name = name;
 			dataChanged(index,index);
 			// modify the path of all files
 			modifyPathOfFiles(n,n->path());
@@ -597,6 +607,13 @@ namespace kt
 		}
 		else
 		{
+			// Check if there is a sibling with the same name
+			foreach (Node* sibling,n->parent->children)
+			{
+				if (sibling != n && sibling->name == name)
+					return false;
+			}
+			
 			n->name = name;
 			n->file->setUserModifiedPath(n->path());
 			dataChanged(index,index);
@@ -694,10 +711,18 @@ namespace kt
 			return;
 		
 		BDecoder dec(state,false,0);
-		BNode* n = dec.decode();
-		if (n && n->getType() == BNode::DICT)
+		BNode* n = 0;
+		try
 		{
-			root->loadExpandedState(index(0,0,QModelIndex()),pm,tv,n);
+			n = dec.decode();
+			if (n && n->getType() == BNode::DICT)
+			{
+				root->loadExpandedState(index(0,0,QModelIndex()),pm,tv,n);
+			}
+		}
+		catch (bt::Error & err)
+		{
+			Out(SYS_GEN|LOG_DEBUG) << "Failed to load expanded state" << endl;
 		}
 		delete n;
 	}
