@@ -32,7 +32,7 @@
 #include <util/functions.h>
 #include <util/fileops.h>
 #include <util/waitjob.h>
-#include <btversion.h>
+#include <version.h>
 #include "upnprouter.h"
 #include "upnpdescriptionparser.h"
 #include "soap.h"
@@ -114,14 +114,16 @@ namespace kt
 	
 	UPnPRouter::UPnPRouter(const QString & server,const KUrl & location,bool verbose) : server(server),location(location),verbose(verbose)
 	{
-		// make the tmp_file unique, current time * a random number should be enough
-		tmp_file = QDir::tempPath() + bt::DirSeparator() + QString("ktorrent_upnp_description-%1.xml").arg(bt::GetCurrentTime() * rand());
 	}
 	
 	
 	UPnPRouter::~UPnPRouter()
 	{
-		qDeleteAll(active_reqs);
+		foreach (HTTPRequest* r,active_reqs)
+		{
+			r->cancel();
+			r->deleteLater();
+		}
 	}
 	
 	void UPnPRouter::addService(const UPnPService & s)
@@ -202,7 +204,7 @@ namespace kt
 		
 		// the protocol
 		a.element = "NewProtocol";
-		a.value = port.proto == TCP ? "TCP" : "UDP";
+		a.value = port.proto == net::TCP ? "TCP" : "UDP";
 		args.append(a);
 		
 		// the local port
@@ -294,7 +296,7 @@ namespace kt
 		
 		// the protocol
 		a.element = "NewProtocol";
-		a.value = port.proto == TCP ? "TCP" : "UDP";
+		a.value = port.proto == net::TCP ? "TCP" : "UDP";
 		args.append(a);
 		
 		
@@ -347,15 +349,18 @@ namespace kt
 				"\r\n").arg(controlurl).arg(location.host()).arg(location.port()).arg(soapact).arg(bt::GetVersionString());
 
 		HTTPRequest* r = new HTTPRequest(http_hdr,query,location.host(),location.port(),verbose);
-		connect(r,SIGNAL(replyError(HTTPRequest* ,const QString& )),
-				this,SLOT(onReplyError(HTTPRequest* ,const QString& )));
-		connect(r,SIGNAL(replyOK(HTTPRequest* ,const QString& )),
-				this,SLOT(onReplyOK(HTTPRequest* ,const QString& )));
-		connect(r,SIGNAL(error(HTTPRequest*, const QString & )),
-				this,SLOT(onError(HTTPRequest*, const QString & )));
-		r->start();
 		if (!at_exit)
+		{
+			connect(r,SIGNAL(replyError(HTTPRequest* ,const QString& )),
+					this,SLOT(onReplyError(HTTPRequest* ,const QString& )));
+			connect(r,SIGNAL(replyOK(HTTPRequest* ,const QString& )),
+					this,SLOT(onReplyOK(HTTPRequest* ,const QString& )));
+			connect(r,SIGNAL(error(HTTPRequest*, const QString & )),
+					this,SLOT(onError(HTTPRequest*, const QString & )));
 			active_reqs.append(r);
+		}
+		
+		r->start();
 		return r;
 	}
 	
@@ -377,6 +382,7 @@ namespace kt
 		
 		updateGUI();
 		active_reqs.removeAll(r);
+		r->deleteLater();
 	}
 	
 	void UPnPRouter::onReplyOK(HTTPRequest* r,const QString &)
