@@ -34,7 +34,7 @@ namespace kt
 {
 	
 	ScheduleItem::ScheduleItem() 
-		: day(0),upload_limit(0),download_limit(0),paused(false),set_conn_limits(false),global_conn_limit(0),torrent_conn_limit(0)
+		: day(0),upload_limit(0),download_limit(0),suspended(false),set_conn_limits(false),global_conn_limit(0),torrent_conn_limit(0)
 	{
 		screensaver_limits = false;
 		ss_download_limit = ss_upload_limit = 0;
@@ -72,7 +72,7 @@ namespace kt
 		end = item.end;
 		upload_limit = item.upload_limit;
 		download_limit = item.download_limit;
-		paused = item.paused;
+		suspended = item.suspended;
 		screensaver_limits = item.screensaver_limits;
 		ss_download_limit = item.ss_download_limit;
 		ss_upload_limit = item.ss_upload_limit;
@@ -89,7 +89,7 @@ namespace kt
 				end == item.end &&
 				upload_limit == item.upload_limit &&
 				download_limit == item.download_limit &&
-				paused == item.paused && 
+				suspended == item.suspended && 
 				set_conn_limits == item.set_conn_limits &&
 				global_conn_limit == item.global_conn_limit &&
 				torrent_conn_limit == item.torrent_conn_limit &&
@@ -107,7 +107,7 @@ namespace kt
 	
 	/////////////////////////////////////////
 
-	Schedule::Schedule()
+	Schedule::Schedule() : enabled(true)
 	{}
 
 
@@ -137,35 +137,56 @@ namespace kt
 		{
 			delete node;
 			Out(SYS_SCD|LOG_NOTICE) << "Decoding " << file << " failed : " << err.toString() << endl;
-			throw bt::Error(i18n("The file %1 is corrupted or not a proper KTorrent schedule file."));
+			throw bt::Error(i18n("The file %1 is corrupted or not a proper KTorrent schedule file.", file));
 		}
 		
 		if (!node)
 		{
 			Out(SYS_SCD|LOG_NOTICE) << "Decoding " << file << " failed !" << endl;
-			throw bt::Error(i18n("The file %1 is corrupted or not a proper KTorrent schedule file."));
+			throw bt::Error(i18n("The file %1 is corrupted or not a proper KTorrent schedule file.", file));
 		}
 		
 		if (node->getType() == BNode::LIST)
 		{
-			BListNode* ln = (BListNode*)node;
-			for (Uint32 i = 0;i < ln->getNumChildren();i++)
+			// Old format
+			parseItems((BListNode*)node);
+		}
+		else if (node->getType() == BNode::DICT)
+		{
+			BDictNode* dict = (BDictNode*)node;
+			BListNode* items = dict->getList("items");
+			if (items)
+				parseItems(items);
+			
+			try
 			{
-				BDictNode* dict = ln->getDict(i);
-				if (!dict)
-					continue;
-				
-				ScheduleItem* item = new ScheduleItem();
-				if (parseItem(item,dict))
-					addItem(item);
-				else
-					delete item;
+				enabled = dict->getInt("enabled") == 1;
+			}
+			catch (...)
+			{
+				enabled = true;
 			}
 		}
 		
 		delete node;
 	}
 	
+	void Schedule::parseItems(BListNode* items)
+	{
+		for (Uint32 i = 0;i < items->getNumChildren();i++)
+		{
+			BDictNode* dict = items->getDict(i);
+			if (!dict)
+				continue;
+			
+			ScheduleItem* item = new ScheduleItem();
+			if (parseItem(item,dict))
+				addItem(item);
+			else
+				delete item;
+		}
+	}
+	
 	bool Schedule::parseItem(ScheduleItem* item,bt::BDictNode* dict)
 	{
 		BValueNode* day = dict->getValue("day");
@@ -173,9 +194,9 @@ namespace kt
 		BValueNode* end = dict->getValue("end");
 		BValueNode* upload_limit = dict->getValue("upload_limit");
 		BValueNode* download_limit = dict->getValue("download_limit");
-		BValueNode* paused = dict->getValue("paused");
+		BValueNode* suspended = dict->getValue("suspended");
 		
-		if (!day || !start || !end || !upload_limit || !download_limit || !paused)
+		if (!day || !start || !end || !upload_limit || !download_limit || !suspended)
 			return false;
 		
 		item->day = day->data().toInt();
@@ -183,7 +204,7 @@ namespace kt
 		item->end = QTime::fromString(end->data().toString());
 		item->upload_limit = upload_limit->data().toInt();
 		item->download_limit = download_limit->data().toInt();
-		item->paused = paused->data().toInt() == 1;
+		item->suspended = suspended->data().toInt() == 1;
 		item->set_conn_limits = false;
 		
 		BDictNode* conn_limits = dict->getDict(QString("conn_limits"));
@@ -227,6 +248,9 @@ namespace kt
 		}
 
 		BEncoder enc(&fptr);
+		enc.beginDict();
+		enc.write("enabled",enabled);
+		enc.write("items");
 		enc.beginList();
 		for (iterator itr = begin();itr != end();itr++)
 		{
@@ -237,7 +261,7 @@ namespace kt
 			enc.write("end"); enc.write(i->end.toString());
 			enc.write("upload_limit"); enc.write(i->upload_limit);
 			enc.write("download_limit"); enc.write(i->download_limit);
-			enc.write("paused"); enc.write((Uint32) (i->paused ? 1 : 0));
+			enc.write("suspended"); enc.write((Uint32) (i->suspended ? 1 : 0));
 			if (i->set_conn_limits)
 			{
 				enc.write("conn_limits"); 
@@ -252,6 +276,7 @@ namespace kt
 			enc.end();
 		}
 		enc.end();
+		enc.end();
 	}
 	
 	bool Schedule::addItem(ScheduleItem* item)
@@ -341,4 +366,10 @@ namespace kt
 		}
 		return false;
 	}
+	
+	void Schedule::setEnabled(bool on)
+	{
+		enabled = on;
+	}
+
 }
