@@ -22,6 +22,7 @@
 #include <kglobal.h>
 #include <klocale.h>
 #include <kcalendarsystem.h>
+#include <QPalette>
 #include <QFontMetricsF>
 #include <QGraphicsRectItem>
 #include <QGraphicsLineItem>
@@ -36,6 +37,7 @@
 #include "bwschedulerpluginsettings.h"
 #include "guidanceline.h"
 
+
 using namespace bt;
 
 namespace kt
@@ -44,7 +46,6 @@ namespace kt
 	WeekScene::WeekScene(QObject* parent)
 			: QGraphicsScene(parent)
 	{
-		setBackgroundBrush(Qt::white);
 		addCalendar();
 	}
 
@@ -65,18 +66,26 @@ namespace kt
 		return wd;
 	}
 	
-	void WeekScene::updateStatusText(int up,int down,bool paused)
+	void WeekScene::updateStatusText(int up,int down,bool suspended,bool enabled)
 	{
-		if (paused)
-			status->setPlainText(i18n("Current schedule: paused"));
+		KLocale* loc = KGlobal::locale();
+		QString msg;
+		if (suspended)
+			msg = i18n("Current schedule: suspended");
 		else if (up > 0 && down > 0)
-			status->setPlainText(i18n("Current schedule: %1 KiB/s download, %2 KiB/s upload",down,up));
+			msg = i18n("Current schedule: %1/s download, %2/s upload",
+				 loc->formatByteSize(down * 1024),loc->formatByteSize(up * 1024));
 		else if (up > 0)
-			status->setPlainText(i18n("Current schedule: unlimited download, %1 KiB/s upload",up));
+			msg = i18n("Current schedule: unlimited download, %1/s upload",loc->formatByteSize(up * 1024));
 		else if (down > 0)
-			status->setPlainText(i18n("Current schedule: %1 KiB/s download, unlimited upload",down));
+			msg = i18n("Current schedule: %1/s download, unlimited upload",loc->formatByteSize(down * 1024));
 		else
-			status->setPlainText(i18n("Current schedule: unlimited upload and download"));
+			msg = i18n("Current schedule: unlimited upload and download");
+		
+		if (!enabled)
+			msg += i18n(" (scheduler disabled)");
+		
+		status->setPlainText(msg);
 	}
 
 	void WeekScene::addCalendar()
