@@ -87,7 +87,7 @@ namespace kt
 		switch (section)
 		{
 			case 2: return i18n("Priority");
-			case 3: return i18n("Preview");
+			case 3: return i18nc("@title:column", "Preview");
 			// xgettext: no-c-format
 			case 4: return i18nc("Percent of File Downloaded", "% Complete");
 			default: return QVariant();
