@@ -33,6 +33,8 @@
 #include "convertdialog.h"
 #include "downloadandconvertjob.h"
 
+using namespace bt;
+
 
 namespace kt
 {
@@ -70,8 +72,12 @@ namespace kt
 		active_job = 0;
 		if (j->error())
 		{
+			Out(SYS_IPF|LOG_NOTICE) << "IP filter update failed: " << j->errorString() << endl;
 			if (mode == Verbose)
+			{
 				((KIO::Job*)j)->ui()->showErrorMessage();
+			}
+			
 			setError(unzip ? UNZIP_FAILED : MOVE_FAILED);
 			emitResult();
 		}
@@ -84,8 +90,12 @@ namespace kt
 		active_job = 0;
 		if (j->error())
 		{
+			Out(SYS_IPF|LOG_NOTICE) << "IP filter update failed: " << j->errorString() << endl;
 			if (mode == Verbose)
+			{
 				((KIO::Job*)j)->ui()->showErrorMessage();
+			}
+			
 			setError(DOWNLOAD_FAILED); 
 			emitResult();
 			return;
@@ -118,8 +128,12 @@ namespace kt
 		active_job = 0;
 		if (j->error())
 		{
+			Out(SYS_IPF|LOG_NOTICE) << "IP filter update failed: " << j->errorString() << endl;
 			if (mode == Verbose)
+			{
 				((KIO::Job*)j)->ui()->showErrorMessage();
+			}
+			
 			setError(MOVE_FAILED);
 			emitResult();
 			return;
@@ -129,8 +143,12 @@ namespace kt
 		KZip* zip = new KZip(zipfile);
 		if (!zip->open(QIODevice::ReadOnly) || !zip->directory())
 		{
+			Out(SYS_IPF|LOG_NOTICE) << "IP filter update failed: cannot open zip file " << zipfile << endl;
 			if (mode == Verbose)
+			{
 				KMessageBox::error(0,i18n("Cannot open zip file %1.",zipfile));
+			}
+			
 			setError(UNZIP_FAILED);
 			emitResult();
 			delete zip;
@@ -154,8 +172,11 @@ namespace kt
 		}
 		else
 		{
+			Out(SYS_IPF|LOG_NOTICE) << "IP filter update failed: no blocklist found in zipfile " << zipfile << endl;
 			if (mode == Verbose)
+			{
 				KMessageBox::error(0,i18n("Cannot find blocklist in zip file %1.",zipfile));
+			}
 			
 			setError(UNZIP_FAILED);
 			emitResult();
@@ -175,8 +196,12 @@ namespace kt
 	{
 		if (j && j->error())
 		{
+			Out(SYS_IPF|LOG_NOTICE) << "IP filter update failed: " << j->errorString() << endl;
 			if (mode == Verbose)
+			{
 				((KIO::Job*)j)->ui()->showErrorMessage();
+			}
+			
 			setError(BACKUP_FAILED);
 			emitResult();
 		}
