@@ -89,6 +89,13 @@ namespace kt
 				home();
 			return;
 		}
+		else if (u.protocol() == "magnet")
+		{
+			int ret = KMessageBox::questionYesNo(0,i18n("Do you want to download this magnet link?"));
+			if (ret == KMessageBox::Yes)
+				openTorrent(u);
+			return;
+		}
 		
 		KIO::TransferJob* j = 0;
 		if (barg.doPost())
@@ -204,9 +211,7 @@ namespace kt
 			else
 			{
 				addToHistory(curr_url);
-				begin(curr_url);
-				write(curr_data.data(),curr_data.size());
-				end();
+				openUrl(curr_url);
 				view()->ensureVisible(0,0);
 				completed();
 			}
